/**
 * @file	tizen_dlp.cpp
 * @brief	external API functions for DLP
 */

#include <dlfcn.h>

#define LIBRARY_PATH "/lib/libprivacy-guard-client.so"

static int first_run = 1;
static void (*privacy_guard_dlp_init)(void) = 0;
static void (*privacy_guard_dlp_check_leak)(const char *, char * const, size_t) = 0;

/**
 * @fn void tizen_dlp_init(void)
 * @brief Initialize the DLP creating the Load Rules and Logging threads
 * @callgraph
 */
void tizen_dlp_init(void)
{
    if (first_run) {
        void *handle = dlopen(LIBRARY_PATH, RTLD_LAZY|RTLD_NODELETE);
        if (handle) {
            privacy_guard_dlp_init = dlsym(handle, "privacy_guard_dlp_init");
            privacy_guard_dlp_check_leak = dlsym(handle, "privacy_guard_dlp_check_leak");
            dlclose(handle);
            first_run = 0;
        }
    }

    if (privacy_guard_dlp_init)
        privacy_guard_dlp_init();
}

/**
 * @fn void tizen_dlp_check_leak(const char *hostname, char * const mem, size_t len)
 * @brief Checks for information leak on a given request string
 *
 * @param[in] hostname					The hostname of the server to which the request will be sent
 * @param[in] mem						Text that we are going to validate for info leak
 * @param[in] len						Size of len in bytes
 *
 * @return  either PRIV_GUARD_DLP_RESULT_ALLOW or PRIV_GUARD_DLP_RESULT_DENY
 * @callgraph
 */
void tizen_dlp_check_leak(const char *hostname, char * const mem, size_t len)
{
    /**
    * Send data to Tizen DLP verification
    */
    if(privacy_guard_dlp_check_leak)
	privacy_guard_dlp_check_leak(hostname, mem, len);
}
